// This file is a part of the Framsticks GDK.
// Copyright (C) 2002-2014  Maciej Komosinski and Szymon Ulatowski.  See LICENSE.txt for details.
// Refer to http://www.framsticks.com/ for further information.

#include <frams/genetics/geno.h>
#include <frams/virtfile/stdiofile.h>
#include <frams/util/sstringutils.h>
#include <frams/genetics/defgenoconv.h>
#include <frams/genetics/genman.h>

/**
 @file
 Sample code: Testing genotype validity

 \include geno_test.cpp
*/

DefaultGenoConvManager gcm; //without this object the application would only handle "format 0" genotypes

int main(int argc,char*argv[])
{
GenMan gm;
Geno::validators.insert(0,&gm); //GenMan is available in this application so let's use the extended validity checking!
// Note: insert() makes it the first validator in the list, this is important for formats that rely on genetic operators to perform reasonable validation,
// otherwise the default validator (genotype converter) would "win" and most converters are less strict in detecting invalid genotypes.
if (argc<=1)
	{
	puts("no genotype");
	return 10;
	}
SString gen(argv[1]);
if (!strcmp(gen,"-"))
	{
	gen=0;
	StdioFILEDontClose in(stdin);
	loadSString(&in,gen);
	}
Geno g(gen);
puts(g.isValid()?"valid":"invalid");
return !g.isValid();
}
